==> glabels_2.1.2.orig.tar.gz: glabels-2.1.2/src/marshal.h <==

#ifndef __gl_marshal_MARSHAL_H__
#define __gl_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (marshal.list:1) */
#define gl_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:BOOLEAN (marshal.list:2) */
#define gl_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:INT (marshal.list:3) */
#define gl_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,INT (marshal.list:4) */
extern void gl_marshal_VOID__INT_INT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:INT,UINT (marshal.list:5) */
extern void gl_marshal_VOID__INT_UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:INT,DOUBLE (marshal.list:6) */
extern void gl_marshal_VOID__INT_DOUBLE (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* VOID:DOUBLE (marshal.list:7) */
#define gl_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE

/* VOID:DOUBLE,DOUBLE (marshal.list:8) */
extern void gl_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:STRING (marshal.list:9) */
#define gl_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* BOOLEAN:OBJECT (marshal.list:10) */
extern void gl_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

G_END_DECLS

#endif /* __gl_marshal_MARSHAL_H__ */

==> glabels-2.2.3.tar.gz: glabels-2.2.3/src/marshal.h <==

#ifndef __gl_marshal_MARSHAL_H__
#define __gl_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (marshal.list:1) */
#define gl_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:INT (marshal.list:2) */
#define gl_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,INT (marshal.list:3) */
extern void gl_marshal_VOID__INT_INT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:INT,UINT (marshal.list:4) */
extern void gl_marshal_VOID__INT_UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:DOUBLE (marshal.list:5) */
#define gl_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE

/* VOID:DOUBLE,DOUBLE (marshal.list:6) */
extern void gl_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:OBJECT (marshal.list:7) */
#define gl_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

G_END_DECLS

#endif /* __gl_marshal_MARSHAL_H__ */
